@@ -86,7 +86,7 @@
 #define KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWIDGETSADDONS_NO_DEPRECATED
-#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KWIDGETSADDONS_NO_DEPRECATED_WARNINGS
 #  define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -96,7 +96,7 @@
 #  ifdef KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
@@ -228,7 +228,7 @@
 #define KWIDGETSADDONS_BUILD_DEPRECATED_SINCE(major, minor) 1
 
 #ifdef KWIDGETSADDONS_NO_DEPRECATED
-#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x55e00
+#  define KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT 0x56000
 #endif
 #ifdef KWIDGETSADDONS_NO_DEPRECATED_WARNINGS
 #  define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0
@@ -238,7 +238,7 @@
 #  ifdef KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE KWIDGETSADDONS_DISABLE_DEPRECATED_BEFORE_AND_AT
 #  else
-#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x55e00
+#    define KWIDGETSADDONS_DEPRECATED_WARNINGS_SINCE 0x56000
 #  endif
 #endif
 
